package com.diagbot.facade;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.client.AiptServiceClient;
import com.diagbot.client.TranServiceClient;
import com.diagbot.client.bean.ConceptBaseVO;
import com.diagbot.client.bean.ConceptExistVO;
import com.diagbot.client.bean.FeatureRate;
import com.diagbot.client.bean.GdbResponse;
import com.diagbot.client.bean.ResponseData;
import com.diagbot.client.bean.SearchData;
import com.diagbot.dto.ConceptBaseDTO;
import com.diagbot.dto.ConceptPushDTO;
import com.diagbot.dto.EMRQuestionDTO;
import com.diagbot.dto.PushDTO;
import com.diagbot.dto.PushEMRDTO;
import com.diagbot.dto.PushKYJDTO;
import com.diagbot.dto.QuestionDTO;
import com.diagbot.dto.QuestionPushDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.DeptVital;
import com.diagbot.entity.QuestionInfo;
import com.diagbot.enums.ConceptTypeEnum;
import com.diagbot.enums.DisTypeEnum;
import com.diagbot.enums.FeatureTypeEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.LisSourceEnum;
import com.diagbot.enums.QuestionTypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.util.ArrayUtil;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.FastJsonUtils;
import com.diagbot.util.ListUtil;
import com.diagbot.util.RespDTOUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.EMRPushVO;
import com.diagbot.vo.HosCodeVO;
import com.diagbot.vo.LisResultVO;
import com.diagbot.vo.PushKYJVO;
import com.diagbot.vo.PushVO;
import com.diagbot.vo.QuestionVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2018/11/20 11:18
 */
@Component
public class PushFacade {
    @Autowired
    private QuestionFacade questionFacade;
    @Autowired
    private DeptVitalFacade deptVitalFacade;
    @Autowired
    private TreatmentFacade treatmentFacade;
    @Autowired
    private LisMappingFacade lisMappingFacade;
    @Autowired
    private DisTypeFacade disTypeFacade;
    @Autowired
    private TranServiceClient tranServiceClient;
    @Autowired
    private AiptServiceClient aiptServiceClient;
    @Autowired
    private AssembleFacade assembleFacade;


    /**
     * 中间层接口
     *
     * @param searchData
     * @return ResponseData
     */
    public ResponseData pushAipt(SearchData searchData) {
        RespDTO<ResponseData> res = aiptServiceClient.aiptData(searchData);
        RespDTOUtil.respNGDeal(res, "中间层没有返回结果");
        return res.data;
    }

    /**
     * 中间层推理-症状……诊断、核心指标
     *
     * @param searchData
     * @return
     */
    public PushDTO pushInnerAipt(SearchData searchData) {
        RespDTO<PushDTO> res = aiptServiceClient.pushInner(searchData);
        RespDTOUtil.respNGDeal(res, "中间层没有返回结果");
        return res.data;
    }

    /**
     * 中间层获取治疗方案
     *
     * @param searchData
     * @return
     */
    public Map<String, Object> getTreatment(SearchData searchData) {
        RespDTO<Map<String, Object>> res = aiptServiceClient.getTreatment(searchData);
        RespDTOUtil.respNGDealCover(res, "中间层没有返回治疗方案");
        return res.data;
    }

    /**
     * 获取量表
     *
     * @param searchData
     * @return
     */
    public Map<String, Object> scale(SearchData searchData) {
        RespDTO<Map<String, Object>> res = aiptServiceClient.scale(searchData);
        RespDTOUtil.respNGDealCover(res, "量表数据暂无内容");
        return res.data;
    }

    /**
     * 推理接口
     *
     * @param pushVO
     * @return
     */
    public PushDTO pushInner(PushVO pushVO) {
        PushDTO pushDTO = new PushDTO();
        SearchData aiSearchData = assembleFacade.assembleData(pushVO);
        PushDTO data = pushInnerAipt(aiSearchData);

        String featureType = pushVO.getFeatureType();
        String[] featureTypes = featureType.split(",|，");
        Set<String> featureTypeSet = new HashSet(Arrays.asList(featureTypes));

        //症状 概念+标签id
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Symptom.getKey()))) {
            List<ConceptPushDTO> symptom = data.getSymptom();
            if (ListUtil.isNotEmpty(symptom)) {
                List<ConceptPushDTO> symptomDTO = addQuestionId(symptom, QuestionTypeEnum.Symptom.getKey());
                pushDTO.setSymptom(symptomDTO);
            }
        }
        //其他史 概念+标签id
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Other.getKey()))) {
        }
        //查体 返回模板（标签列表）+标记标签
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Vital.getKey()))) {
            //查体模板
            List<ConceptPushDTO> vitals = data.getVital();
            ConceptPushDTO dept = data.getDept();
            List<QuestionPushDTO> moduleVitalDTO = getVitalModule(dept, pushVO);
            pushDTO.setModuleVital(moduleVitalDTO);
            //查体标记项
            if (ListUtil.isNotEmpty(vitals)) {
                List<ConceptPushDTO> vitalDTOList = addQuestionId(vitals, QuestionTypeEnum.Vital.getKey());
                pushDTO.setVital(vitalDTOList);
                if (ListUtil.isNotEmpty(vitalDTOList)) {
                    List<Long> vitalIds = vitalDTOList.stream().map(vital -> vital.getId()).collect(Collectors.toList());
                    pushDTO.setVitalIds(vitalIds);
                }
            }
        }
        //化验  标签列表
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Lis.getKey()))) {
            List<ConceptPushDTO> labs = data.getLab();
            if (ListUtil.isNotEmpty(labs)) {
                //公表项转套餐项
                Map<String, List<String>> lisMapping = lisMappingFacade.getLisMappingByUniqueName();
                List<String> nameList = Lists.newLinkedList();
                Map<String, Long> lisMap = new LinkedHashMap<>();
                List<ConceptPushDTO> lisDTO = Lists.newLinkedList();
                for (ConceptPushDTO lab : labs) {
                    if (ListUtil.isNotEmpty(lisMapping.get(lab.getName()))) {
                        //匹配出多个套餐项默认取第一个
                        String name = lisMapping.get(lab.getName()).get(0);
                        if (nameList.contains(name)) {
                            continue;
                        }
                        nameList.add(name);
                    }
                }
                if (ListUtil.isNotEmpty(nameList)) {
                    ConceptExistVO conceptExistVO = new ConceptExistVO();
                    conceptExistVO.setNameList(nameList);
                    conceptExistVO.setType(ConceptTypeEnum.Lis.getKey());
                    RespDTO<Map<String, Long>> respDTO = aiptServiceClient.getConceptMapByNameAndType(conceptExistVO);
                    if (RespDTOUtil.respIsOK(respDTO)) {
                        lisMap = respDTO.data;
                    }
                }
                for (String name : nameList) {
                    ConceptPushDTO conceptPushDTO = new ConceptPushDTO();
                    conceptPushDTO.setName(name);
                    conceptPushDTO.setLibType(ConceptTypeEnum.Lis.getKey());
                    if (lisMap.containsKey(name) && lisMap.get(name) != null) {
                        conceptPushDTO.setConceptId(lisMap.get(name));
                    }
                    lisDTO.add(conceptPushDTO);
                }
                if (ListUtil.isNotEmpty(lisDTO)) {
                    lisDTO = addQuestionId(lisDTO, ConceptTypeEnum.Lis.getKey());
                }
                pushDTO.setLab(lisDTO);
            }
        }
        //辅检  标签列表
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Pacs.getKey()))) {
            pushDTO.setPacs(data.getPacs());
        }
        //诊断 返回分类+标签列表
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.Disease.getKey()))) {
            pushDTO.setDis(data.getDis());
        }
        //推送指标 featuretype=22
        if (featureTypeSet.contains(String.valueOf(FeatureTypeEnum.MedicalIndication.getKey()))) {
            pushDTO.setMedicalIndications(data.getMedicalIndications());
        }
        return pushDTO;
    }

    /**
     * 治疗方案推送
     *
     * @param pushVO
     * @return
     */
    public Map<String, Object> pushTreatment(PushVO pushVO) {
        SearchData searchData = assembleFacade.assembleData(pushVO);
        Map<String, Object> data = getTreatment(searchData);
        data = treatmentFacade.getTreatment(data, pushVO.getPatientId());
        return data;
    }


    /**
     * 获取返回结果标签
     *
     * @param nameList
     * @param pushVO
     * @param type
     * @return
     */
    public List<QuestionDTO> getTagList(List<String> nameList, PushVO pushVO, Integer type) {
        List<QuestionDTO> questionDTOList = Lists.newLinkedList();
        QueryWrapper<QuestionInfo> questionInfoQueryWrapper = new QueryWrapper();
        questionInfoQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey()).
                in("tag_name", nameList).
                eq("type", type);
        List<QuestionInfo> questionInfoList = questionFacade.list(questionInfoQueryWrapper);
        Map<String, QuestionInfo> questionMap = EntityUtil.makeEntityMap(questionInfoList, "tagName");
        for (String name : nameList) {
            QuestionDTO questionDTO = new QuestionDTO();
            if (questionMap.get(name) != null) {
                QuestionVO questionVO = new QuestionVO();
                questionVO.setAge(pushVO.getAge());
                questionVO.setSexType(pushVO.getSex());
                questionVO.setId(questionMap.get(name).getId());
                questionDTO = questionFacade.getById(questionVO);
                if (questionDTO == null || questionDTO.getId() == null) {
                    questionDTO = new QuestionDTO();
                    questionDTO.setTagName(name);
                    questionDTO.setName(name);
                }
            } else {
                questionDTO.setTagName(name);
                questionDTO.setName(name);
            }
            questionDTOList.add(questionDTO);
        }
        return questionDTOList;
    }

    /**
     * 推理接口-快易检
     *
     * @param pushKYJVO
     * @return
     */
    public PushKYJDTO pushKYJ(PushKYJVO pushKYJVO) {
        PushVO pushVO = new PushVO();
        pushVO.setAge(pushKYJVO.getAge());
        pushVO.setSex(pushKYJVO.getSex());
        pushVO.setFeatureType(pushKYJVO.getFeatureType());

        //化验结果
        List<LisResultVO> lisResultVOList = BeanUtil.listCopyTo(pushKYJVO.getLisResultList(), LisResultVO.class);
        for (LisResultVO lisResultVO : lisResultVOList) {
            lisResultVO.setSource(LisSourceEnum.Outer.getKey());
        }
        pushVO.setLis(lisResultVOList);

        SearchData searchData = assembleFacade.assembleData(pushVO);
        ResponseData responseData = pushAipt(searchData);
        PushKYJDTO pushKYJDTO = new PushKYJDTO();
        pushKYJDTO.setLabs(responseData.getLabs());
        pushKYJDTO.setDis(responseData.getDis());
        return pushKYJDTO;
    }

    /**
     * 获取查体模板
     *
     * @param dept
     * @param pushVO
     * @return
     */
    public List<QuestionPushDTO> getVitalModule(ConceptPushDTO dept, PushVO pushVO) {
        List<QuestionPushDTO> vitalDTO = Lists.newLinkedList();
        if (dept.getConceptId() == null) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "全科信息未维护");
        }
        QueryWrapper<DeptVital> deptVitalQueryWrapper = new QueryWrapper<>();
        deptVitalQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey()).
                eq("dept_id", dept.getConceptId()).
                orderByAsc("order_no");
        List<DeptVital> deptVitalList = deptVitalFacade.list(deptVitalQueryWrapper);
        //科室模板为空时，取全科模板
        if (deptVitalList.size() == 0 && dept.getName().equals("全科") == false) {
            ConceptBaseVO conceptBaseVO = new ConceptBaseVO();
            conceptBaseVO.setName("全科");
            conceptBaseVO.setLibType(ConceptTypeEnum.DEPARTMENT.getKey());
            RespDTO<ConceptBaseDTO> res = aiptServiceClient.existConcept(conceptBaseVO);
            RespDTOUtil.respNGDeal(res, "全科信息未维护");
            BeanUtil.copyProperties(res.data, dept);
            deptVitalQueryWrapper = new QueryWrapper<>();
            deptVitalQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey()).
                    eq("dept_id", dept.getConceptId()).
                    orderByAsc("order_no");
            deptVitalList = deptVitalFacade.list(deptVitalQueryWrapper);
        }
        //标签列表
        for (DeptVital deptVital : deptVitalList) {
            QuestionVO questionVO = new QuestionVO();
            QuestionPushDTO questionPushDTO = new QuestionPushDTO();
            questionVO.setAge(pushVO.getAge());
            questionVO.setSexType(pushVO.getSex());
            questionVO.setId(deptVital.getVitalId());
            QuestionDTO questionDTO = questionFacade.getById(questionVO);
            if (questionDTO != null && questionDTO.getId() != null) {
                BeanUtil.copyProperties(questionDTO, questionPushDTO);
                ConceptBaseVO conceptBaseVO = new ConceptBaseVO();
                conceptBaseVO.setName(questionDTO.getTagName());
                conceptBaseVO.setLibType(ConceptTypeEnum.Vital.getKey());
                RespDTO<ConceptBaseDTO> res = aiptServiceClient.existConcept(conceptBaseVO);
                if (RespDTOUtil.respIsOK(res)) {
                    ConceptBaseDTO vitalConcept = res.data;
                    questionPushDTO.setConceptId(vitalConcept.getConceptId());
                    questionPushDTO.setLibType(ConceptTypeEnum.Vital.getKey());
                }
                vitalDTO.add(questionPushDTO);
            }
        }
        return vitalDTO;
    }

    /**
     * 电子病历评级-数据服务模式推理
     *
     * @param emrPushVO
     * @return
     */
    public PushEMRDTO pushEMR(EMRPushVO emrPushVO) {
        Boolean isDocking = tranServiceClient.isDocking().data;
        PushEMRDTO pushEMRDTO = new PushEMRDTO();
        HosCodeVO hosCodeVO = new HosCodeVO();
        hosCodeVO.setHosCode(emrPushVO.getHosCode());
        PushVO pushVO = new PushVO();
        BeanUtil.copyProperties(emrPushVO, pushVO);
        //化验项转公表内容,参数处理
        if (ListUtil.isNotEmpty(pushVO.getLis())) {
            Map<String, Map<String, String>> lisConfigMap = new LinkedHashMap<>();
            Map<String, String> lisConfigMap_emptyItemName = new LinkedHashMap<>();
            if (isDocking) {
                lisConfigMap = tranServiceClient.getLisConfigByHosCode_NotEmptyItemName(hosCodeVO).data;
                lisConfigMap_emptyItemName = tranServiceClient.getLisConfigByHosCode_EmptyItemName(hosCodeVO).data;
            } else {
                lisConfigMap = lisMappingFacade.getLisMapping_NotEmptyItemName();
                lisConfigMap_emptyItemName = lisMappingFacade.getLisConfig_EmptyItemName();
            }
            List<LisResultVO> lisResultVOList = pushVO.getLis();
            for (LisResultVO lisResultVO : lisResultVOList) {
                if (StringUtil.isNotBlank(lisResultVO.getName())) {
                    if (StringUtil.isNotBlank(lisResultVO.getDetailName())) {
                        lisResultVO.setUniqueName(lisConfigMap.get(lisResultVO.getName()).get(lisResultVO.getDetailName()));
                    } else {
                        lisResultVO.setUniqueName(lisConfigMap_emptyItemName.get(lisResultVO.getName()));
                    }
                }
            }
            pushVO.setLis(lisResultVOList);
        }

        SearchData searchData = assembleFacade.assembleData(pushVO);
        ResponseData data = pushAipt(searchData);
        String featureType = pushVO.getFeatureType();
        String[] featureTypes = featureType.split(",|，");
        Set<String> featureTypeSet = new HashSet(Arrays.asList(featureTypes));

        if (featureTypeSet.contains(String.valueOf(QuestionTypeEnum.Symptom.getKey()))) {
            List<FeatureRate> symptomFeature = data.getSymptom();
            if (symptomFeature.size() > 0) {
                List<EMRQuestionDTO> symptomList = Lists.newLinkedList();
                for (FeatureRate featureRate : symptomFeature) {
                    EMRQuestionDTO symptom = new EMRQuestionDTO();
                    symptom.setName(featureRate.getFeatureName());
                    symptom.setUniqueName(featureRate.getFeatureName());
                    symptomList.add(symptom);
                }
                pushEMRDTO.setSymptomList(symptomList);
            }
        }
        if (featureTypeSet.contains(String.valueOf(QuestionTypeEnum.Vital.getKey()))) {
            List<FeatureRate> vitalFeature = data.getVitals();
            if (vitalFeature.size() > 0) {
                List<EMRQuestionDTO> vitalList = Lists.newLinkedList();
                for (FeatureRate featureRate : vitalFeature) {
                    EMRQuestionDTO vital = new EMRQuestionDTO();
                    vital.setName(featureRate.getFeatureName());
                    vital.setUniqueName(featureRate.getFeatureName());
                    vitalList.add(vital);
                }
                pushEMRDTO.setVitalList(vitalList);
            }
        }
        if (featureTypeSet.contains(String.valueOf(QuestionTypeEnum.Lis.getKey()))) {
            List<FeatureRate> lisFeatures = data.getLabs();
            if (lisFeatures.size() > 0) {
                Map<String, List<String>> lisMappingByUniqueName = new LinkedHashMap<>();
                if (isDocking) {
                    lisMappingByUniqueName = tranServiceClient.getLisConfigByUniqueNameAndHosCode(hosCodeVO).data;
                } else {
                    lisMappingByUniqueName = lisMappingFacade.getLisMappingByUniqueName();
                }
                List<EMRQuestionDTO> lisList = Lists.newLinkedList();
                for (FeatureRate featureRate : lisFeatures) {
                    EMRQuestionDTO lis = new EMRQuestionDTO();
                    lis.setUniqueName(featureRate.getFeatureName());
                    if (ListUtil.isNotEmpty(lisMappingByUniqueName.get(featureRate.getFeatureName()))) {
                        lis.setName(lisMappingByUniqueName.get(featureRate.getFeatureName()).get(0));
                    }
                    lisList.add(lis);
                }
                pushEMRDTO.setLisList(lisList);
            }
        }
        if (featureTypeSet.contains(String.valueOf(QuestionTypeEnum.Pacs.getKey()))) {
            List<FeatureRate> pacsFeatures = data.getPacs();
            if (pacsFeatures.size() > 0) {
                Map<String, List<String>> pacsConfigMapByUniqueName = new LinkedHashMap<>();
                if (isDocking) {
                    pacsConfigMapByUniqueName = tranServiceClient.getPacsConfigByUniqueNameAndHosCode(hosCodeVO).data;
                }
                List<EMRQuestionDTO> pacsList = Lists.newLinkedList();
                for (FeatureRate featureRate : pacsFeatures) {
                    EMRQuestionDTO pacs = new EMRQuestionDTO();
                    pacs.setUniqueName(featureRate.getFeatureName());
                    if (isDocking) {
                        if (ListUtil.isNotEmpty(pacsConfigMapByUniqueName.get(featureRate.getFeatureName()))) {
                            pacs.setName(pacsConfigMapByUniqueName.get(featureRate.getFeatureName()).get(0));
                        }
                    } else {
                        pacs.setName(featureRate.getFeatureName());
                    }
                    pacsList.add(pacs);
                }
                pushEMRDTO.setPacsList(pacsList);
            }
        }
        if (featureTypeSet.contains(String.valueOf(QuestionTypeEnum.Disease.getKey()))) {
            List<FeatureRate> dis = data.getDis();
            List<String> disNameList = dis.stream().map(disease -> disease.getFeatureName()).collect(Collectors.toList());
            Map<String, List<EMRQuestionDTO>> retDisMap = new LinkedHashMap<>();
            Map<String, String> disMap = tranServiceClient.getDiseaseIcdByHosCode(hosCodeVO).data;

            //诊断分类
            for (FeatureRate featureRate : dis) {
                if (StringUtil.isBlank(featureRate.getDesc())) {
                    featureRate.setDesc("{\"可能诊断\":\"\"}");
                }
                Map<String, Object> descMap = FastJsonUtils.getJsonToMap(featureRate.getDesc());
                for (String disClass : descMap.keySet()) {
                    List<EMRQuestionDTO> retDisList = Lists.newLinkedList();
                    if (retDisMap.get(disClass) != null) {
                        retDisList = retDisMap.get(disClass);
                    }
                    EMRQuestionDTO retDis = new EMRQuestionDTO();
                    retDis.setUniqueName(featureRate.getFeatureName());
                    if (isDocking) {
                        //对接模式转icd10名称
                        retDis.setName(disMap.get(featureRate.getFeatureName()));
                    } else {
                        retDis.setName(featureRate.getFeatureName());
                    }
                    retDisList.add(retDis);
                    retDisMap.put(disClass, retDisList);
                }
            }
            //警惕
            searchData = new SearchData();
            searchData.setDiag(String.join(",", disNameList));
            RespDTO<GdbResponse> graphRes = aiptServiceClient.highRisk(searchData);
            Map<String, String> graphResult = graphRes.data.getResult();
            if (graphResult.size() > 0) {
                List<EMRQuestionDTO> highRiskDisList = Lists.newLinkedList();
                for (Map.Entry<String, String> entry : graphResult.entrySet()) {
                    if (entry.getValue().equals("1")) {
                        EMRQuestionDTO hrDis = new EMRQuestionDTO();
                        hrDis.setUniqueName(entry.getKey());
                        if (isDocking) {
                            hrDis.setName(disMap.get(entry.getKey()));
                        } else {
                            hrDis.setName(entry.getValue());
                        }
                        highRiskDisList.add(hrDis);
                    }
                }
                retDisMap.put("警惕", highRiskDisList);
            }
            pushEMRDTO.setDis(retDisMap);
        }
        return pushEMRDTO;
    }

    /**
     * 获取管理评估内容，titles不为空，返回指定内容，否则返回所有内容
     *
     * @param pushVO
     * @param titles
     * @return
     */
    public Map<String, JSONObject> getManagementEvaluationContent(PushVO pushVO, List<String> titles) {
        String[] diseases = pushVO.getDiag().split(",|，");

        if (ArrayUtil.isEmpty(diseases)) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "请输入诊断名称");
        }
        String disease = diseases[0];
        //判断是否为慢病
        if (!disTypeFacade.judgeByDisName(disease, DisTypeEnum.CHRONIC.getKey())) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "非慢病，不能获取管理评估内容");
        }

        SearchData searchData = assembleFacade.assembleData(pushVO);
        ResponseData data = pushAipt(searchData);
        Map<String, JSONObject> managementEvaluationMap = data.getManagementEvaluation();
        if (managementEvaluationMap == null) {
            managementEvaluationMap = new LinkedHashMap<>();
            managementEvaluationMap.put("疗效评估", JSONObject.parseObject("{ \"rows\":[ { \"controltype\":0, \"name\":\"血压控制情况\", \"details\":[ { \"detailName\":\"正常\", \"state\":1 }, { \"detailName\":\"1级\", \"state\":0 }, { \"detailName\":\"2级\", \"state\":0 }, { \"detailName\":\"3级\", \"state\":0 } ] }, { \"controltype\":1, \"name\":\"BMI控制情况\", \"details\":[ { \"detailName\":\"体重过低\", \"state\":1 }, { \"detailName\":\"体重达标\", \"state\":0 }, { \"detailName\":\"肥胖前期\", \"state\":0 }, { \"detailName\":\"肥胖\", \"state\":0 } ] }, { \"controltype\":0, \"name\":\"血脂控制情况\", \"details\":[ { \"detailName\":\"高血脂\", \"state\":1 } ] } ] }"));
            managementEvaluationMap.put("糖尿病分级管理", JSONObject.parseObject("{ \"rows\":[ { \"name\":\"血压控制情况\", \"controltype\":0, \"details\":[ { \"detailName\":\"常规管理\", \"state\":1 }, { \"detailName\":\"强化管理\", \"state\":0 } ] } ] }"));
        }
        Map<String, JSONObject> retMap = new LinkedHashMap<>();
        if (ListUtil.isEmpty(titles)) {
            retMap = managementEvaluationMap;
        } else {
            for (String title : titles) {
                if (managementEvaluationMap.get(title) != null) {
                    retMap.put(title, managementEvaluationMap.get(title));
                }
            }
        }
        return retMap;
    }

    /**
     * 概念关联标签，添加标签id ——症状，化验
     *
     * @param concepts
     * @param type
     * @return
     */
    public List<ConceptPushDTO> addQuestionId(List<ConceptPushDTO> concepts, Integer type) {
        QueryWrapper<QuestionInfo> questionInfoQueryWrapper = new QueryWrapper<>();
        List<String> nameList = concepts.stream().map(concept -> concept.getName()).collect(Collectors.toList());
        questionInfoQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey()).in("tag_name", nameList).eq("type", type);
        List<QuestionInfo> questionInfoList = questionFacade.list(questionInfoQueryWrapper);
        if (ListUtil.isNotEmpty(questionInfoList)) {
            Map<String, QuestionInfo> questionInfoMap = EntityUtil.makeEntityMap(questionInfoList, "tagName");
            for (ConceptPushDTO concept : concepts) {
                if (questionInfoMap.containsKey(concept.getName())) {
                    concept.setId(questionInfoMap.get(concept.getName()).getId());
                }
            }
        }
        return concepts;
    }
}