package com.diagbot.facade;

import com.diagbot.client.AiptServiceClient;
import com.diagbot.dto.ConceptBaseDTO;
import com.diagbot.dto.ConceptRetrievalDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.Symptom;
import com.diagbot.entity.SymptomWrapper;
import com.diagbot.service.impl.SymptomServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.RespDTOUtil;
import com.diagbot.vo.ConceptUsualVO;
import com.diagbot.vo.RetrievalVO;
import com.diagbot.vo.SymptomSearchVO;
import com.diagbot.vo.SymptomUsualVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @Description: 症状
 * @Author: ztg
 * @Date: 2018/10/23 16:33
 */
@Component
public class SymptomFacade extends SymptomServiceImpl{
    @Autowired
    AiptServiceClient aiptServiceClient;

    /**
     *  获取常用症状
     *
     * @return
     */
    public List<Symptom> getUsualFac(SymptomUsualVO symptomUsualVO) {
        ConceptUsualVO conceptUsualVO = new ConceptUsualVO();
        BeanUtil.copyProperties(symptomUsualVO,conceptUsualVO);
        conceptUsualVO.setDeptName("全科");
        conceptUsualVO.setType(1);
        //从知识库获取常用标签
        RespDTO<List<ConceptBaseDTO>> conceptBaseDTORespDTO = aiptServiceClient.getConceptUsual(conceptUsualVO);
        RespDTOUtil.respNGDeal(conceptBaseDTORespDTO,"获取常用标签失败");
        List<Symptom> symptomList = BeanUtil.listCopyTo(conceptBaseDTORespDTO.data,Symptom.class);
        return symptomList;
    }


    /**
     * 根据部位partIds获取症状信息
     *
     * @param map 参数
     * @return
     */
    public List<SymptomWrapper> getByPartIdsFac(Map map) {
        return this.getByPartIds(map);
    }


    /**
     * 症状检索
     *
     * @param symptomSearchVO
     * @return 检索的症状
     */
    public List<Symptom> searchFac(SymptomSearchVO symptomSearchVO) {
        //调用aipt-service服务
        RetrievalVO retrievalVO = new RetrievalVO();
        retrievalVO.setType(1);
        retrievalVO.setInputStr(symptomSearchVO.getName());
        retrievalVO.setAge(symptomSearchVO.getAge());
        retrievalVO.setSexType(symptomSearchVO.getSexType());
        RespDTO<List<ConceptRetrievalDTO>> condeptRerievalS =  aiptServiceClient.retrivelConceptInfo(retrievalVO);
        RespDTOUtil.respNGDeal(condeptRerievalS,"获取标签失败");
        List<Symptom> symptomList = new ArrayList<>();
        Symptom symptom = new Symptom();
        //封装
        for (ConceptRetrievalDTO conceptRetrievalDTO : condeptRerievalS.data) {
            symptom = new Symptom();
            symptom.setConceptId(conceptRetrievalDTO.getSelfId());
            symptom.setName(conceptRetrievalDTO.getSelfName());
            symptomList.add(symptom);
        }
        return symptomList;
    }

}
